pub trait RawParams {
type Elem: ?Sized;
}Expand description
The RawParams trait is used to denote objects capable of being used as a paramater
within a neural network or machine learning context. More over, it provides us with an
ability to associate some generic element type with the parameter and thus allows us to
consider so-called parameter spaces. If we allow a parameter space to simply be a
collection of points then we can refine the definition downstream to consider specific
interpolations, distributions, or manifolds. In other words, we are trying to construct
a tangible configuration space for our models so that we can reason about optimization
and training in a more formal manner.
Note: This trait is sealed and cannot be implemented outside of this crate.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".